@@ -4,6 +4,7 @@ import (
 	"fmt"
 	"k8s.io/klog"
 	"net/http"
+	"os"
 	"strconv"
 	"strings"
 	"time"
@@ -58,6 +59,16 @@ var metricOVNDBMonitor = prometheus.NewGaugeVec(prometheus.GaugeOpts{
 	},
 )
 
+var metricDBSize = prometheus.NewGaugeVec(prometheus.GaugeOpts{
+	Namespace: metrics.MetricOvnNamespace,
+	Subsystem: metrics.MetricOvnSubsystemDBRaft,
+	Name:      "db_size",
+	Help:      "The size of the database file associated with the OVN DB component."},
+	[]string{
+		"db_name",
+	},
+)
+
 // ClusterStatus metrics
 var metricDBClusterCID = prometheus.NewGaugeVec(prometheus.GaugeOpts{
 	Namespace: metrics.MetricOvnNamespace,
@@ -269,6 +280,16 @@ func ovnDBStatusMetricsUpdater(direction, database string) {
 	}
 }
 
+func ovnDBSizeMetricsUpdater(direction, database string) {
+	dbFile := fmt.Sprintf("/etc/openvswitch/ovn%s_db.db", direction)
+	fileInfo, err := os.Stat(dbFile)
+	if err != nil {
+		klog.Errorf("Failed to get the DB size for database %s: %v", database, err)
+		return
+	}
+	metricDBSize.WithLabelValues(database).Set(float64(fileInfo.Size()))
+}
+
 func ovnDBMemoryMetricsUpdater(direction, database string) {
 	var stdout, stderr string
 	var err error
@@ -315,7 +336,7 @@ var (
 func getOvnDbVersionInfo() {
 	stdout, _, err := util.RunOVSDBClient("-V")
 	if err == nil && strings.HasPrefix(stdout, "ovsdb-client (Open vSwitch) ") {
-		ovnDbVersion = strings.Fields(stdout)[2]
+		ovnDbVersion = strings.Fields(stdout)[3]
 	}
 	sockPath := "unix:/var/run/openvswitch/ovnnb_db.sock"
 	stdout, _, err = util.RunOVSDBClient("get-schema-version", sockPath, "OVN_Northbound")
@@ -358,6 +379,7 @@ var OvnDBExporterCommand = cli.Command{
 		prometheus.MustRegister(metricOVNDBLeader)
 		prometheus.MustRegister(metricOVNDBMonitor)
 		prometheus.MustRegister(metricOVNDBSessions)
+		prometheus.MustRegister(metricDBSize)
 		prometheus.MustRegister(prometheus.NewGaugeFunc(
 			prometheus.GaugeOpts{
 				Namespace: metrics.MetricOvnNamespace,
@@ -391,17 +413,14 @@ var OvnDBExporterCommand = cli.Command{
 
 		// functions responsible for collecting the values and updating the prometheus metrics
 		go func() {
-			for {
-				ovnDBStatusMetricsUpdater("nb", "OVN_Northbound")
-				ovnDBStatusMetricsUpdater("sb", "OVN_Southbound")
-				time.Sleep(30 * time.Second)
+			dirDbMap := map[string]string{
+				"nb": "OVN_Northbound",
+				"sb": "OVN_Southbound",
 			}
-		}()
-
-		go func() {
-			for {
-				ovnDBMemoryMetricsUpdater("nb", "OVN_Northbound")
-				ovnDBMemoryMetricsUpdater("sb", "OVN_Southbound")
+			for direction, database := range dirDbMap {
+				ovnDBStatusMetricsUpdater(direction, database)
+				ovnDBMemoryMetricsUpdater(direction, database)
+				ovnDBSizeMetricsUpdater(direction, database)
 				time.Sleep(30 * time.Second)
 			}
 		}()
@@ -455,7 +474,7 @@ func getOVNDBClusterStatusInfo(timeout int, direction, database string) (cluster
 		stdout, stderr, err = util.RunOVNSBAppCtl(fmt.Sprintf("--timeout=%d", timeout),
 			"cluster/status", database)
 	} else {
-		stdout, stderr, err = util.RunOVNSBAppCtl(fmt.Sprintf("--timeout=%d", timeout),
+		stdout, stderr, err = util.RunOVNNBAppCtl(fmt.Sprintf("--timeout=%d", timeout),
 			"cluster/status", database)
 	}
 	if err != nil {
